@@ -20,15 +20,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt '
-           '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt '
-           '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt',
+           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-march=armv5te -O2 -pipe -fstack-protector-strong '
+ 'CONFIGURE_CFLAGS': '-march=armv5te -O3 -pipe -fstack-protector-strong '
                      '-fno-plt',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
@@ -42,7 +42,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong "
+                "'CFLAGS=-march=armv5te -O3 -pipe -fstack-protector-strong "
                 "-fno-plt' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' "
                 "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
@@ -541,7 +541,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -603,22 +603,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt '
-              '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt '
-              '-march=armv5te -O2 -pipe -fstack-protector-strong -fno-plt',
+              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wno-cast-function-type '
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
-                   '-Wall -march=armv5te -O2 -pipe -fstack-protector-strong '
-                   '-fno-plt -march=armv5te -O2 -pipe -fstack-protector-strong '
-                   '-fno-plt -march=armv5te -O2 -pipe -fstack-protector-strong '
+                   '-Wall -march=armv5te -O3 -pipe -fstack-protector-strong '
+                   '-fno-plt -march=armv5te -O3 -pipe -fstack-protector-strong '
+                   '-fno-plt -march=armv5te -O3 -pipe -fstack-protector-strong '
                    '-fno-plt -std=c99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wno-cast-function-type '
@@ -632,10 +632,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
-                        '-O3 -Wall -march=armv5te -O2 -pipe '
-                        '-fstack-protector-strong -fno-plt -march=armv5te -O2 '
+                        '-O3 -Wall -march=armv5te -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt -march=armv5te -O3 '
                         '-pipe -fstack-protector-strong -fno-plt '
-                        '-march=armv5te -O2 -pipe -fstack-protector-strong '
+                        '-march=armv5te -O3 -pipe -fstack-protector-strong '
                         '-fno-plt -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wno-cast-function-type '
@@ -701,7 +701,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.7 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 1,
